biom.table.Table.delimited_self — biom-format.org

# biom-format.org

## biom.table.Table.delimited_self

`Table.` `delimited_self`(delim='\t', header_key=None, header_value=None, metadata_formatter=<type 'str'>, observation_column_name='#OTU ID')

  Return self as a string in a delimited form

  Default str output for the Table is just row/col ids and table data without any metadata

  Including observation metadata in output: If `header_key` is not `None`, the observation metadata with that name will be included in the delimited output. If `header_value` is also not `None`, the observation metadata will use the provided `header_value` as the observation metadata name (i.e., the column header) in the delimited output.

  `metadata_formatter`: a function which takes a metadata entry and returns a formatted version that should be written to file

  `observation_column_name`: the name of the first column in the output table, corresponding to the observation IDs. For example, the default will look something like:

  > #OTU ID Sample1 Sample2 OTU1 10 2 OTU2 4 8